C     PREPROCESSOR TO CALCULATE CONDUCTANCES AND STORAGE CAPACITIES
C     FOR A RADIAL SIMULATION USING THE GENERAL FINITE-DIFFERENCE
C     (GFD) PACKAGE OF THE U.S.G.S. MODULAR MODEL
C
C            BY THOMAS E. REILLY AND ARLEN W. HARBAUGH
C                    VERSION 1.0  -- APRIL 1992
C        VERSION 1.1  -- JANUARY 1996, declarations added RSRegan
C
      INTEGER MXCOL, MXROW
      PARAMETER (MXCOL=200,MXROW=100)
C
      REAL A, ALPHA, AREA(MXCOL), ASQ, B, C, CC(MXROW,MXCOL),
     &     CR(MXROW,MXCOL), DELZ(MXROW), KR(MXROW), KZ(MXROW), PI,
     &     R(MXCOL), RINTER, RW, SC(MXROW,MXCOL), SS(MXROW)
      INTEGER I, INUNIT, IOUTU1, IOUTU2, IR, J, LOCAT, NCOL, NNC, NROW
      CHARACTER*80 IFNAME, OFNAM1, OFNAM2
C
      REAL SQRT, ALOG
      INTRINSIC SQRT, ALOG
C
C     set string for use if RCS ident and UNIX what commands
      IFNAME =
     &'$Id: radmod.f,v 1.2 1996/01/19 21:13:48 rsregan Exp rsregan $'
      IFNAME = '@(#)RADMOD - A MODFLOW preprocessor program'
      IFNAME = '@(#)RADMOD - Ground Water, v. 31, no. 3, Reilly and Harb
     &augh, 1993'
      IFNAME = '@(#)RADMOD - Contact: h2osoft@usgs.gov'
      IFNAME = '@(#)RADMOD - Version: 1.1x 1996/01/19'
C
      PI=3.14159
C
C  Ask for file names and open the files
      INUNIT=10
      IOUTU1=11
      IOUTU2=12
      WRITE(*,1)
1     FORMAT(5X,'ENTER INPUT FILE NAME')
      READ(*,2) IFNAME
2     FORMAT(A)
      OPEN(INUNIT,FILE=IFNAME,STATUS='OLD')
      WRITE(*,3)
3     FORMAT(5X,'ENTER GFD PACKAGE OUTPUT FILE NAME')
      READ(*,2) OFNAM1
      OPEN(IOUTU1,FILE=OFNAM1)
      WRITE(*,4)
4     FORMAT(5X,'ENTER OUTPUT FILE NAME FOR LATERAL GRID SPACING')
      READ(*,2) OFNAM2
      OPEN(IOUTU2,FILE=OFNAM2)
C
C  Read first record, and check that arrays are dimensioned large enough
      READ(INUNIT,10) ALPHA,RW,NCOL,NROW,LOCAT
10    FORMAT(2F10.0,3I5)
      IF(NCOL.GT.MXCOL .OR. NROW.GT.MXROW) THEN
        WRITE(*,*) ' NCOL GREATER THAN MXCOL OR NROW GREATER THAN MXROW'
        STOP
      END IF
C
C  Calculate lateral node location
      R(1)=RW
      DO 11 I=2,NCOL
        R(I)=ALPHA*R(I-1)
11    CONTINUE
C
C  Calculate cell area
      ASQ=ALPHA*ALPHA
      RINTER=ALPHA*RW*SQRT(2./(ASQ+1.))
      AREA(1)=PI*(RINTER*RINTER-RW*RW)
      AREA(2)=AREA(1)*ASQ*2.
      NNC=NCOL-1
      DO 12 I=3,NNC
        AREA(I)=AREA(I-1)*ASQ
12    CONTINUE
      AREA(NCOL)=AREA(NNC)*ASQ/2.
C
C  READ VERTICAL CHARACTERISTICS
      DO 25 J=1,NROW
        READ(INUNIT,21) IR,DELZ(IR),KR(IR),KZ(IR),SS(IR)
21      FORMAT(I5,4F10.0)
25    CONTINUE
C
C  GENERATE CR, CC, AND SC ARRAYS
      DO 30 J=1,NROW
      DO 29 I=1,NCOL
        SC(J,I)=SS(J)*AREA(I)*DELZ(J)
        IF(I.EQ.NCOL) THEN
          CR(J,I)=0.0
        ELSE
          CR(J,I)=2.*PI*KR(J)*DELZ(J)/ALOG(ALPHA)
        END IF
        IF(J.EQ.NROW) THEN
          CC(J,I)=0.0
        ELSE
          A=2.*KZ(J)*AREA(I)/DELZ(J)
          IF(J.EQ.1) A=KZ(J)*AREA(I)/DELZ(J)
          B=2.*KZ(J+1)*AREA(I)/DELZ(J+1)
          IF(J+1.EQ.NROW) B=KZ(J+1)*AREA(I)/DELZ(J+1)
          C=1./A + 1./B
          CC(J,I)=1./C
        END IF
29    CONTINUE
30    CONTINUE
C
C  WRITE GFD FILE
C    ISS,IGFDCB
      WRITE(IOUTU1,41)
41    FORMAT(9X,'0',9X,'0',2X, 'ISS,IGFDCB')
C    LAYCON
      WRITE(IOUTU1,42) 0
42    FORMAT(I2)
C    DELR
      WRITE(IOUTU1,43) LOCAT,'DELR'
43    FORMAT(I10,7X,'1.0',1X,'(5F15.0)',20X,'0',2X,A)
      WRITE(IOUTU1,44) (AREA(I),I=1,NCOL)
44    FORMAT(1P,5E15.5)
C    DELC
      WRITE(IOUTU1,43) LOCAT,'DELC'
      WRITE(IOUTU1,44) 1.,(0.0,I=2,NROW)
C    SC
      WRITE(IOUTU1,43) LOCAT,'SC'
      DO 50 J=1,NROW
      WRITE(IOUTU1,44) (SC(J,I),I=1,NCOL)
50    CONTINUE
C    CR
      WRITE(IOUTU1,43) LOCAT,'CR'
      DO 52 J=1,NROW
      WRITE(IOUTU1,44) (CR(J,I),I=1,NCOL)
52    CONTINUE
C    CC
      WRITE(IOUTU1,43) LOCAT,'CC'
      DO 53 J=1,NROW
      WRITE(IOUTU1,44) (CC(J,I),I=1,NCOL)
53    CONTINUE
C
C  Write lateral node locations
      WRITE(IOUTU2,60)
60    FORMAT(1X,'Lateral node location:')
      WRITE(IOUTU2,44) (R(I),I=1,NCOL)
C
      STOP
      END
